@@ -1,5 +1,5 @@
 /*
- * Copyright © 2010-2011 inria.  All rights reserved.
+ * Copyright © 2010-2012 Inria.  All rights reserved.
  * Copyright © 2011-2012 Université Bordeaux 1
  * Copyright © 2011 Cisco Systems, Inc.  All rights reserved.
  * See COPYING in top-level directory.
@@ -221,7 +221,7 @@ static void hwloc_distances__set_from_string(struct hwloc_topology *topology,
   } else {
     /* parse a comma separated list of distances */
     for(i=0; i<nbobjs*nbobjs; i++) {
-      distances[i] = atof(tmp);
+      distances[i] = (float) atof(tmp);
       next = strchr(tmp, ',');
       if (next) {
         tmp = next+1;
@@ -255,8 +255,12 @@ void hwloc_distances_set_from_env(struct hwloc_topology *topology)
     char *env, envname[64];
     snprintf(envname, sizeof(envname), "HWLOC_%s_DISTANCES", hwloc_obj_type_string(type));
     env = getenv(envname);
-    if (env)
+    if (env) {
+      hwloc_localeswitch_declare;
+      hwloc_localeswitch_init();
       hwloc_distances__set_from_string(topology, type, env);
+      hwloc_localeswitch_fini();
+    }
   }
 }
 
@@ -545,6 +549,10 @@ hwloc_distances__finalize_logical(struct hwloc_topology *topology,
   }
   relative_depth = objs[0]->depth - root->depth; /* this assume that we have distances between objects of the same level */
 
+  if (nbobjs != hwloc_get_nbobjs_inside_cpuset_by_depth(topology, root->cpuset, root->depth + relative_depth))
+    /* the root does not cover the right number of objects, maybe we failed to insert a root (bad intersect or so). */
+    return;
+
   /* get the logical index offset, it's the min of all logical indexes */
   minl = UINT_MAX;
   for(i=0; i<nbobjs; i++)
@@ -842,7 +850,7 @@ hwloc__groups_by_distances(struct hwloc_topology *topology,
       memset(&(groupsizes[0]), 0, sizeof(groupsizes[0]) * nbgroups);
       for(i=0; i<nbgroups; i++) {
           /* create the Group object */
-          hwloc_obj_t group_obj;
+          hwloc_obj_t group_obj, res_obj;
           group_obj = hwloc_alloc_setup_object(HWLOC_OBJ_GROUP, -1);
           group_obj->cpuset = hwloc_bitmap_alloc();
           group_obj->attr->group.depth = topology->next_group_depth;
@@ -860,8 +868,10 @@ hwloc__groups_by_distances(struct hwloc_topology *topology,
             }
           hwloc_debug_1arg_bitmap("adding Group object with %u objects and cpuset %s\n",
                                   groupsizes[i], group_obj->cpuset);
-          hwloc__insert_object_by_cpuset(topology, group_obj,
-					 fromuser ? hwloc_report_user_distance_error : hwloc_report_os_error);
+          res_obj = hwloc__insert_object_by_cpuset(topology, group_obj,
+						   fromuser ? hwloc_report_user_distance_error : hwloc_report_os_error);
+          assert(res_obj == group_obj); /* somebody else created groups here, things went wrong ?! */
+
           groupobjs[i] = group_obj;
       }
 
@@ -923,7 +933,7 @@ hwloc_group_by_distances(struct hwloc_topology *topology)
   unsigned nbobjs;
   struct hwloc_os_distances_s * osdist;
   char *env;
-  float accuracies[5] = { 0.0, 0.01, 0.02, 0.05, 0.1 };
+  float accuracies[5] = { 0.0f, 0.01f, 0.02f, 0.05f, 0.1f };
   unsigned nbaccuracies = 5;
   hwloc_obj_t group_obj;
   int verbose = 0;
@@ -946,7 +956,7 @@ hwloc_group_by_distances(struct hwloc_topology *topology)
   } else if (strcmp(env, "try")) {
     /* use the given value */
     nbaccuracies = 1;
-    accuracies[0] = atof(env);
+    accuracies[0] = (float) atof(env);
   } /* otherwise try all values */
 
 #ifdef HWLOC_DEBUG
@@ -995,7 +1005,7 @@ hwloc_group_by_distances(struct hwloc_topology *topology)
        * this group will be merged into a regular object if the matrix isn't strangely incomplete
        */
       group_obj = hwloc_alloc_setup_object(HWLOC_OBJ_GROUP, -1);
-      group_obj->attr->group.depth = topology->next_group_depth++;
+      group_obj->attr->group.depth = (unsigned) -1;
       group_obj->cpuset = hwloc_bitmap_alloc();
       for(i=0; i<nbobjs; i++) {
 	/* assemble the group cpuset */
