@@ -1,7 +1,7 @@
 /*
  * Copyright © 2009 CNRS
- * Copyright © 2009-2011 INRIA.  All rights reserved.
- * Copyright © 2009-2010 Université Bordeaux 1
+ * Copyright © 2009-2012 Inria.  All rights reserved.
+ * Copyright © 2009-2010, 2012 Université Bordeaux 1
  * Copyright © 2011 Cisco Systems, Inc.  All rights reserved.
  * See COPYING in top-level directory.
  */
@@ -19,12 +19,15 @@
 #ifdef HAVE_SYS_CPUSET_H
 #include <sys/cpuset.h>
 #endif
+#ifdef HAVE_SYSCTL
+#include <sys/sysctl.h>
+#endif
 
 #include <hwloc.h>
 #include <private/private.h>
 #include <private/debug.h>
 
-#ifdef HAVE_SYS_CPUSET_H
+#if defined(HAVE_SYS_CPUSET_H) && defined(HAVE_CPUSET_SETAFFINITY)
 static void
 hwloc_freebsd_bsd2hwloc(hwloc_bitmap_t hwloc_cpuset, const cpuset_t *cpuset)
 {
@@ -161,41 +164,87 @@ hwloc_freebsd_get_thread_cpubind(hwloc_topology_t topology __hwloc_attribute_unu
 #endif
 #endif
 
-void
-hwloc_look_freebsd(struct hwloc_topology *topology)
+#ifdef HAVE_SYSCTL
+static void
+hwloc_freebsd_node_meminfo_info(struct hwloc_topology *topology)
 {
-  unsigned nbprocs = hwloc_fallback_nbprocessors(topology);
-
-#ifdef HAVE__SC_LARGE_PAGESIZE
-  topology->levels[0][0]->attr->machine.huge_page_size_kB = sysconf(_SC_LARGE_PAGESIZE);
+       int mib[2] = { CTL_HW, HW_PHYSMEM };
+       size_t len = sizeof(topology->levels[0][0]->memory.local_memory);
+       sysctl(mib, 2, &topology->levels[0][0]->memory.local_memory, &len, NULL, 0);
+}
 #endif
 
-  hwloc_set_freebsd_hooks(topology);
-  hwloc_look_x86(topology, nbprocs);
+static int
+hwloc_look_freebsd(struct hwloc_backend *backend)
+{
+  struct hwloc_topology *topology = backend->topology;
+  unsigned nbprocs = hwloc_fallback_nbprocessors(topology);
 
-  hwloc_setup_pu_level(topology, nbprocs);
+  if (!topology->levels[0][0]->cpuset) {
+    /* Nobody (even the x86 backend) created objects yet, setup basic objects */
+    hwloc_alloc_obj_cpusets(topology->levels[0][0]);
+    hwloc_setup_pu_level(topology, nbprocs);
+  }
 
+  /* Add FreeBSD specific information */
+#ifdef HAVE_SYSCTL
+  hwloc_freebsd_node_meminfo_info(topology);
+#endif
   hwloc_obj_add_info(topology->levels[0][0], "Backend", "FreeBSD");
+  if (topology->is_thissystem)
+    hwloc_add_uname_info(topology);
+  return 1;
 }
 
 void
-hwloc_set_freebsd_hooks(struct hwloc_topology *topology)
+hwloc_set_freebsd_hooks(struct hwloc_binding_hooks *hooks __hwloc_attribute_unused,
+			struct hwloc_topology_support *support __hwloc_attribute_unused)
 {
-#ifdef HAVE_SYS_CPUSET_H
-  topology->set_thisproc_cpubind = hwloc_freebsd_set_thisproc_cpubind;
-  topology->get_thisproc_cpubind = hwloc_freebsd_get_thisproc_cpubind;
-  topology->set_thisthread_cpubind = hwloc_freebsd_set_thisthread_cpubind;
-  topology->get_thisthread_cpubind = hwloc_freebsd_get_thisthread_cpubind;
-  topology->set_proc_cpubind = hwloc_freebsd_set_proc_cpubind;
-  topology->get_proc_cpubind = hwloc_freebsd_get_proc_cpubind;
+#if defined(HAVE_SYS_CPUSET_H) && defined(HAVE_CPUSET_SETAFFINITY)
+  hooks->set_thisproc_cpubind = hwloc_freebsd_set_thisproc_cpubind;
+  hooks->get_thisproc_cpubind = hwloc_freebsd_get_thisproc_cpubind;
+  hooks->set_thisthread_cpubind = hwloc_freebsd_set_thisthread_cpubind;
+  hooks->get_thisthread_cpubind = hwloc_freebsd_get_thisthread_cpubind;
+  hooks->set_proc_cpubind = hwloc_freebsd_set_proc_cpubind;
+  hooks->get_proc_cpubind = hwloc_freebsd_get_proc_cpubind;
 #ifdef hwloc_thread_t
 #if HAVE_DECL_PTHREAD_SETAFFINITY_NP
-  topology->set_thread_cpubind = hwloc_freebsd_set_thread_cpubind;
+  hooks->set_thread_cpubind = hwloc_freebsd_set_thread_cpubind;
 #endif
 #if HAVE_DECL_PTHREAD_GETAFFINITY_NP
-  topology->get_thread_cpubind = hwloc_freebsd_get_thread_cpubind;
+  hooks->get_thread_cpubind = hwloc_freebsd_get_thread_cpubind;
 #endif
 #endif
 #endif
   /* TODO: get_last_cpu_location: find out ki_lastcpu */
 }
+
+static struct hwloc_backend *
+hwloc_freebsd_component_instantiate(struct hwloc_disc_component *component,
+				    const void *_data1 __hwloc_attribute_unused,
+				    const void *_data2 __hwloc_attribute_unused,
+				    const void *_data3 __hwloc_attribute_unused)
+{
+  struct hwloc_backend *backend;
+  backend = hwloc_backend_alloc(component);
+  if (!backend)
+    return NULL;
+  backend->discover = hwloc_look_freebsd;
+  return backend;
+}
+
+static struct hwloc_disc_component hwloc_freebsd_disc_component = {
+  HWLOC_DISC_COMPONENT_TYPE_CPU,
+  "freebsd",
+  HWLOC_DISC_COMPONENT_TYPE_GLOBAL,
+  hwloc_freebsd_component_instantiate,
+  50,
+  NULL
+};
+
+const struct hwloc_component hwloc_freebsd_component = {
+  HWLOC_COMPONENT_ABI,
+  HWLOC_COMPONENT_TYPE_DISC,
+  0,
+  &hwloc_freebsd_disc_component
+};
